@@ -1,5 +1,5 @@
-# sentinel.tcl v2.60 (29 March 2001)
-# Copyright 1998-2001 by slennox <slennox@egghelp.org>
+# sentinel.tcl v2.70 (15 April 2002)
+# Copyright 1998-2002 by slennox
 # slennox's eggdrop page - http://www.egghelp.org/
 
 # Flood protection system for eggdrop, with integrated BitchX CTCP
@@ -14,20 +14,26 @@
 # v2.50 - Locktimes of less than 30 were erroneously allowed.
 #         putquick -next is now supported (eggdrop 1.5+) for faster channel
 #         lock.
-#         Ban mechanism now checks if flooders are coming from the same
+#       - Ban mechanism now checks if flooders are coming from the same
 #         domain or ident and performs wildcard bans instead of banning
 #         each IP/host individually.
-#         Added tsunami detection to the avalanche flood detection system.
-#         Variables are now cleared after removing a channel.
-#         Removed unnecessary botonchan checks throughout components where
+#       - Added tsunami detection to the avalanche flood detection system.
+#       - Variables are now cleared after removing a channel.
+#       - Removed unnecessary botonchan checks throughout components where
 #         botisop already checks for that.
-#         Removed all unnecessary use of parentheses.
+#       - Removed all unnecessary use of parentheses.
 # v2.60 - Modified putquick compatibility proc.
-#         Added sl_wideban option to make domain/ident bans optional.
-#         Fixed typos in various ban-related functions.
-#         Unused procs are now unloaded.
-#         Wildcard bans covering domains/idents were not doing proper
+#       - Added sl_wideban option to make domain/ident bans optional.
+#       - Fixed typos in various ban-related functions.
+#       - Unused procs are now unloaded.
+#       - Wildcard bans covering domains/idents were not doing proper
 #         checks on join-part flooders.
+# v2.70 - Fixed "allbans" error which could occur when sl_wideban is
+#         disabled.
+#       - Added sl_masktype option, currently offering three different
+#         ban/ignore mask types.
+#       - Merged unsets in sl_unsetarray.
+#       - Changed use of "split" in timers to the less ugly "list".
 #
 # sentinel.tcl is centered around its channel lock mechanism. It sets the
 # channel +mi (moderated and invite-only) whenever a substantial flood on
@@ -82,9 +88,12 @@
 #   bot's internal ban list until it expires.
 # - For greater protection against large channel floods, I recommend you
 #   also use a channel limiter script, such as chanlimit.tcl.
+# - There is a trade-off between convenience and security. The more
+#   automation you enable, the more stress the bot will be under during a
+#   flood and the more stuff it will be sending to the server.
 # - Where security is paramount, have one or two bots that aren't running
 #   sentinel.tcl. Since sentinel.tcl is a complex script with many
-#   automated and convenience features, there is a small potential for
+#   automated and convenience features, there is a potential for
 #   vulnerabilities.
 
 # The following flood settings are in number:seconds format, 0:0 to
@@ -177,6 +186,17 @@ set sl_banmax 100
 set sl_igtime 240
 # Valid settings: 1 or higher.
 
+# Select the type of hostmask to use when banning and/or ignoring flooders.
+# There are three to choose from:
+#   0 - *!*@machine.domain.com / *!*@555.555.555.555
+#   1 - *!*ident@machine.domain.com / *!*ident@555.555.555.555
+#   2 - *!*ident@*.domain.com / *!*ident@555.555.555.*
+# The default option, 0, is strongly recommended for most situations, and
+# provides the best level of protection. The other two options are provided
+# mainly for special cases.
+set sl_masktype 0
+# Valid settings: 0, 1, or 2, depending on the hostmask type you wish to use.
+
 # Length of time in seconds to set channel +i if flooded. If set to 0, +i
 # will not be removed automatically.
 set sl_ilocktime 120
@@ -256,11 +276,11 @@ proc sl_ctcp {nick uhost hand dest key arg} {
     if {$nick == $botnick} {return 0}
     if {$sl_ban && !$sl_locked($chan) && ![matchattr $hand f|f $chan]} {
       lappend sl_ccbannick($chan) $nick ; lappend sl_ccbanhost($chan) [string tolower $uhost]
-      utimer [lindex $sl_ccflood 1] [split "sl_ccbanqueue $chan"]
+      utimer [lindex $sl_ccflood 1] [list sl_ccbanqueue $chan]
     }
     if {$sl_flooded($chan)} {return 1}
     incr sl_ccqueue($chan)
-    utimer [lindex $sl_ccflood 1] [split "sl_ccqueuereset $chan"]
+    utimer [lindex $sl_ccflood 1] [list sl_ccqueuereset $chan]
     if {$sl_ccqueue($chan) >= [lindex $sl_ccflood 0]} {
       sl_lock $chan "CTCP flood" ${botnet-nick} ; return 1
     }
@@ -270,11 +290,11 @@ proc sl_ctcp {nick uhost hand dest key arg} {
       sl_ignore [string tolower $uhost] $hand "CTCP flooder" ; return 1
     }
     incr sl_bcqueue
-    utimer [lindex $sl_bcflood 1] "incr sl_bcqueue -1"
+    utimer [lindex $sl_bcflood 1] {incr sl_bcqueue -1}
     if {$sl_bcqueue >= [lindex $sl_bcflood 0]} {
       putlog "sentinel: CTCP flood detected on me! Stopped answering CTCPs temporarily."
       set sl_bflooded 1
-      utimer [lindex $sl_bcflood 1] "set sl_bflooded 0"
+      utimer [lindex $sl_bcflood 1] {set sl_bflooded 0}
       if {[info commands sendnote] != ""} {
         foreach recipient $sl_note {
           if {[validuser $recipient]} {
@@ -288,7 +308,7 @@ proc sl_ctcp {nick uhost hand dest key arg} {
 
   if {!$sl_bxsimul} {return 0}
   if {$sl_bxonestack} {return 1}
-  set sl_bxonestack 1 ; utimer 2 "set sl_bxonestack 0"
+  set sl_bxonestack 1 ; utimer 2 {set sl_bxonestack 0}
   switch -exact -- $key {
     "CLIENTINFO" {
       set bxcmd [string toupper $arg]
@@ -390,11 +410,11 @@ proc sl_bmflood {nick uhost hand text} {
     sl_ignore [string tolower $uhost] $hand "MSG flooder" ; return 0
   }
   incr sl_bmqueue
-  utimer [lindex $sl_bmflood 1] "incr sl_bmqueue -1"
+  utimer [lindex $sl_bmflood 1] {incr sl_bmqueue -1}
   if {$sl_bmqueue >= [lindex $sl_bmflood 0]} {
     putlog "sentinel: MSG flood detected on me! Stopped answering MSGs temporarily."
     set sl_bflooded 1
-    utimer [lindex $sl_bmflood 1] "set sl_bflooded 0"
+    utimer [lindex $sl_bmflood 1] {set sl_bflooded 0}
     if {[info commands sendnote] != ""} {
       foreach recipient $sl_note {
         if {[validuser $recipient]} {
@@ -426,11 +446,11 @@ proc sl_avflood {from keyword arg} {
     set hand [nick2hand $nick $chan]
     if {$sl_ban && !$sl_locked($chan) && $nick != $botnick && ![matchattr $hand f|f $chan]} {
       lappend sl_avbannick($chan) $nick ; lappend sl_avbanhost($chan) [string tolower $uhost]
-      utimer [lindex $sl_avflood 1] [split "sl_avbanqueue $chan"]
+      utimer [lindex $sl_avflood 1] [list sl_avbanqueue $chan]
     }
     if {$sl_flooded($chan)} {return 0}
     incr sl_avqueue($chan)
-    utimer [lindex $sl_avflood 1] [split "sl_avqueuereset $chan"]
+    utimer [lindex $sl_avflood 1] [list sl_avqueuereset $chan]
     if {$sl_avqueue($chan) >= [lindex $sl_avflood 0]} {
       sl_lock $chan "AVALANCHE/TSUNAMI flood" ${botnet-nick}
     }
@@ -451,13 +471,13 @@ proc sl_nkflood {nick uhost hand chan newnick} {
   if {[isop $newnick $chan]} {return 0}
   if {$sl_ban && !$sl_locked($chan) && $nick != $botnick && ![matchattr $hand f|f $chan]} {
     lappend sl_nkbanhost($chan) [string tolower $uhost]
-    utimer [lindex $sl_nkflood 1] [split "sl_nkbanqueue $chan"]
+    utimer [lindex $sl_nkflood 1] [list sl_nkbanqueue $chan]
   }
   if {!$sl_nickkick && $sl_flooded($chan) && $sl_locked($chan)} {
     putserv "KICK $chan $newnick :NICK flooder"
     set sl_nickkick 1 ; set sl_nkflooding($chan) [unixtime]
     if {$sl_ban} {
-      set bhost *!*[string tolower [string range $uhost [string first @ $uhost] end]]
+      set bhost [string tolower [sl_masktype $uhost]]
       if {$sl_globalban} {
         if {[llength [banlist]] < $sl_banmax && ![isban $bhost] && ![matchban $bhost]} {
           newban $bhost sentinel "NICK flooder" $sl_ban
@@ -468,12 +488,12 @@ proc sl_nkflood {nick uhost hand chan newnick} {
         }
       }
     }
-    utimer [expr [rand 2] + 3] "set sl_nickkick 0"
+    utimer [expr [rand 2] + 3] {set sl_nickkick 0}
     return 0
   }
   if {$sl_flooded($chan)} {return 0}
   incr sl_nkqueue($chan)
-  utimer [lindex $sl_nkflood 1] [split "sl_nkqueuereset $chan"]
+  utimer [lindex $sl_nkflood 1] [list sl_nkqueuereset $chan]
   if {$sl_nkqueue($chan) >= [lindex $sl_nkflood 0]} {
     sl_lock $chan "NICK flood" ${botnet-nick}
   }
@@ -485,14 +505,14 @@ proc sl_jflood {nick uhost hand chan} {
   if {$nick == $botnick} {
     sl_setarray $chan
   } else {
-    set ihost *!*[string tolower [string range $uhost [string first @ $uhost] end]]
+    set ihost [string tolower [sl_masktype $uhost]]
     if {[isignore $ihost]} {
       killignore $ihost
     }
     set chan [string tolower $chan]
     if {[lsearch -exact $sl_boflood 0] == -1 && [sl_checkbogus [lindex [split $uhost @] 0]]} {
       if {!$sl_locked($chan) && ![matchattr $hand f|f $chan]} {
-        set bhost *!*[string tolower [string range $uhost [string first @ $uhost] end]]
+        set bhost [string tolower [sl_masktype $uhost]]
         if {$sl_boban && [botisop $chan] && !$sl_flooded($chan)} {
           putserv "KICK $chan $nick :BOGUS username"
           if {$sl_globalban} {
@@ -507,12 +527,12 @@ proc sl_jflood {nick uhost hand chan} {
         }
         if {$sl_ban} {
           lappend sl_bobannick($chan) $nick ; lappend sl_bobanhost($chan) [string tolower $uhost]
-          utimer [lindex $sl_boflood 1] [split "sl_bobanqueue $chan"]
+          utimer [lindex $sl_boflood 1] [list sl_bobanqueue $chan]
         }
       }
       if {!$sl_flooded($chan)} {
         incr sl_boqueue($chan)
-        utimer [lindex $sl_boflood 1] [split "sl_boqueuereset $chan"]
+        utimer [lindex $sl_boflood 1] [list sl_boqueuereset $chan]
         if {$sl_boqueue($chan) >= [lindex $sl_boflood 0]} {
           sl_lock $chan "BOGUS joins" ${botnet-nick}
         }
@@ -521,11 +541,11 @@ proc sl_jflood {nick uhost hand chan} {
     if {[lsearch -exact $sl_jflood 0] == -1} {
       if {$sl_ban && !$sl_locked($chan) && ![matchattr $hand f|f $chan]} {
         lappend sl_jbannick($chan) $nick ; lappend sl_jbanhost($chan) [string tolower $uhost]
-        utimer [lindex $sl_jflood 1] [split "sl_jbanqueue $chan"]
+        utimer [lindex $sl_jflood 1] [list sl_jbanqueue $chan]
       }
       if {$sl_flooded($chan)} {return 0}
       incr sl_jqueue($chan)
-      utimer [lindex $sl_jflood 1] [split "sl_jqueuereset $chan"]
+      utimer [lindex $sl_jflood 1] [list sl_jqueuereset $chan]
       if {$sl_jqueue($chan) >= [lindex $sl_jflood 0] && $sl_pqueue($chan) >= [lindex $sl_jflood 0]} {
         sl_lock $chan "JOIN-PART flood" ${botnet-nick}
       }
@@ -544,18 +564,18 @@ proc sl_pflood {nick uhost hand chan {msg ""}} {
   if {[lsearch -exact $sl_jflood 0] != -1} {return 0}
   if {$nick == $botnick} {
     if {![validchan $chan]} {
-      timer 5 [split "sl_unsetarray $chan"]
+      timer 5 [list sl_unsetarray $chan]
     }
     return 0
   }
   set chan [string tolower $chan]
   if {$sl_ban && !$sl_locked($chan) && ![matchattr $hand f|f $chan]} {
     lappend sl_pbannick($chan) $nick ; lappend sl_pbanhost($chan) [string tolower $uhost]
-    utimer [lindex $sl_jflood 1] [split "sl_pbanqueue $chan"]
+    utimer [lindex $sl_jflood 1] [list sl_pbanqueue $chan]
   }
   if {$sl_flooded($chan)} {return 0}
   incr sl_pqueue($chan)
-  utimer [lindex $sl_jflood 1] [split "sl_pqueuereset $chan"]
+  utimer [lindex $sl_jflood 1] [list sl_pqueuereset $chan]
   return 0
 }
 
@@ -566,32 +586,32 @@ proc sl_pfloodk {nick uhost hand chan kicked reason} {
   set chan [string tolower $chan]
   if {$sl_flooded($chan)} {return 0}
   incr sl_pqueue($chan)
-  utimer [lindex $sl_jflood 1] [split "sl_pqueuereset $chan"]
+  utimer [lindex $sl_jflood 1] [list sl_pqueuereset $chan]
   return 0
 }
 
 proc sl_lock {chan flood detected} {
   global botnet-nick sl_bflooded sl_cfnotice sl_flooded sl_ilocktime sl_mlocktime sl_note
-  if {$detected == ${botnet-nick}} {
+  if {[string tolower $detected] == [string tolower ${botnet-nick}]} {
     set sl_flooded($chan) 1 ; set sl_bflooded 1
     if {[botisop $chan]} {
       sl_quicklock $chan
       sl_killutimer "sl_unlock $chan *"
       sl_killutimer "set sl_bflooded 0"
       if {$sl_mlocktime} {
-        utimer $sl_mlocktime [split "sl_unlock $chan m"]
+        utimer $sl_mlocktime [list sl_unlock $chan m]
       }
       if {$sl_ilocktime} {
-        utimer $sl_ilocktime [split "sl_unlock $chan i"]
+        utimer $sl_ilocktime [list sl_unlock $chan i]
       }
-      utimer 120 "set sl_bflooded 0"
+      utimer 120 {set sl_bflooded 0}
       putlog "sentinel: $flood detected on $chan! Channel locked temporarily."
       if {$sl_cfnotice != ""} {
         puthelp "NOTICE $chan :$sl_cfnotice"
       }
     } else {
       putlog "sentinel: $flood detected on $chan! Cannot lock channel because I'm not opped."
-      utimer 120 "set sl_bflooded 0"
+      utimer 120 {set sl_bflooded 0}
     }
   } else {
     putlog "sentinel: $flood detected by $detected on $chan!"
@@ -599,7 +619,7 @@ proc sl_lock {chan flood detected} {
   if {[info commands sendnote] != ""} {
     foreach recipient $sl_note {
       if {[validuser $recipient]} {
-        if {$detected == ${botnet-nick}} {
+        if {[string tolower $detected] == [string tolower ${botnet-nick}]} {
           sendnote SENTINEL $recipient "$flood detected on $chan."
         } else {
           sendnote SENTINEL $recipient "$flood detected by $detected on $chan."
@@ -617,8 +637,8 @@ proc sl_unlock {chan umode} {
     set sl_flooded($chan) 1 ; set sl_bflooded 1
     sl_killutimer "sl_unlock $chan *"
     sl_killutimer "set sl_bflooded 0"
-    utimer $sl_mlocktime [split "sl_unlock $chan m"] ; utimer $sl_ilocktime [split "sl_unlock $chan i"]
-    utimer 120 "set sl_bflooded 0"
+    utimer $sl_mlocktime [list sl_unlock $chan m] ; utimer $sl_ilocktime [list sl_unlock $chan i]
+    utimer 120 {set sl_bflooded 0}
   } else {
     set sl_flooded($chan) 0
     if {![botisop $chan]} {return 0}
@@ -647,7 +667,7 @@ proc sl_mode {nick uhost hand chan mode victim} {
   if {$mode == "+b" && $sl_bfmaxbans && !$sl_bfull($chan) && ![string match *i* [lindex [split [getchanmode $chan]] 0]] && [botisop $chan] && [llength [chanbans $chan]] >= $sl_bfmaxbans} {
     putserv "MODE $chan +i"
     set sl_bfull($chan) 1
-    utimer 5 [split "set sl_bfull($chan) 0"]
+    utimer 5 [list set sl_bfull($chan) 0]
     putlog "sentinel: locked $chan due to full ban list!"
     if {$sl_bfnotice != ""} {
       puthelp "NOTICE $chan :$sl_bfnotice"
@@ -663,7 +683,7 @@ proc sl_mode {nick uhost hand chan mode victim} {
     set sl_locked($chan) 1
     if {$sl_ban} {
       sl_killutimer "sl_*banqueue $chan"
-      utimer 7 [split "sl_dokicks $chan"] ; utimer 16 [split "sl_setbans $chan"]
+      utimer 7 [list sl_dokicks $chan] ; utimer 16 [list sl_setbans $chan]
     }
   } elseif {$mode == "-i" || $mode == "-m"} {
     set sl_locked($chan) 0
@@ -749,8 +769,8 @@ proc sl_setbans {chan} {
       }
     }
   }
+  set allbans [sl_dfilter [concat $sl_ccbanhost($chan) $sl_avbanhost($chan) $sl_nkbanhost($chan) $sl_bobanhost($chan) $blist]]
   if {$sl_wideban} {
-    set allbans [sl_dfilter [concat $sl_ccbanhost($chan) $sl_avbanhost($chan) $sl_nkbanhost($chan) $sl_bobanhost($chan) $blist]]
     sl_ban $chan [sl_dcheck $allbans] "MULTIPLE IDENT/HOST flooders"
   }
   sl_ban $chan $sl_ccbanhost($chan) "CTCP flooder" ; set sl_ccbanhost($chan) ""
@@ -761,7 +781,7 @@ proc sl_setbans {chan} {
   set sl_jbanhost($chan) "" ; set sl_pbanhost($chan) ""
   if {$sl_shortlock && $sl_kflooders <= 2 && [llength $allbans] <= 2 && [expr [unixtime] - $sl_unlocked($chan)] > 120} {
     sl_killutimer "sl_unlock $chan *"
-    utimer 10 [split "sl_unlock $chan mi"]
+    utimer 10 [list sl_unlock $chan mi]
   }
   return 0
 }
@@ -779,8 +799,8 @@ proc sl_dfilter {list} {
 proc sl_dcheck {bhosts} {
   set blist ""
   foreach bhost $bhosts {
-    set baddr [string tolower [lindex [split [maskhost $bhost] "@"] 1]]
-    set bident [string trimleft [string tolower [lindex [split $bhost "@"] 0]] "~"]
+    set baddr [lindex [split [maskhost $bhost] "@"] 1]
+    set bident [string trimleft [lindex [split $bhost "@"] 0] "~"]
     if {![info exists baddrs($baddr)]} {
       set baddrs($baddr) 1
     } else {
@@ -791,7 +811,7 @@ proc sl_dcheck {bhosts} {
     } else {
       incr bidents($bident)
     }
-  }  
+  }
   foreach baddr [array names baddrs] {
     if {$baddrs($baddr) >= 2} {
       lappend blist *!*@$baddr
@@ -812,7 +832,7 @@ proc sl_ban {chan blist reason} {
       foreach bhost $blist {
         if {![string match *!* $bhost]} {
           if {[matchban *!$bhost]} {continue}
-          set bhost *!*[string range $bhost [string first @ $bhost] end]
+          set bhost [sl_masktype $bhost]
           if {[isban $bhost]} {continue}
         } else {
           if {[isban $bhost]} {continue}
@@ -822,7 +842,7 @@ proc sl_ban {chan blist reason} {
             }
           }
         }
-        if {[llength [banlist]] >= $sl_banmax || [isban $bhost]} {continue}
+        if {[llength [banlist]] >= $sl_banmax} {continue}
         newban $bhost sentinel $reason $sl_ban
         putlog "sentinel: banned $bhost ($reason)"
         sl_ignore $bhost * $reason
@@ -831,7 +851,7 @@ proc sl_ban {chan blist reason} {
       foreach bhost $blist {
         if {![string match *!* $bhost]} {
           if {[matchban *!$bhost $chan]} {continue}
-          set bhost *!*[string range $bhost [string first @ $bhost] end]
+          set bhost [sl_masktype $bhost]
           if {[isban $bhost $chan]} {continue}
         } else {
           if {[isban $bhost $chan]} {continue}
@@ -841,7 +861,7 @@ proc sl_ban {chan blist reason} {
             }
           }
         }
-        if {[llength [banlist $chan]] >= $sl_banmax || [isban $bhost $chan]} {continue}
+        if {[llength [banlist $chan]] >= $sl_banmax} {continue}
         newchanban $chan $bhost sentinel $reason $sl_ban
         putlog "sentinel: banned $bhost on $chan ($reason)"
         sl_ignore $bhost * $reason
@@ -858,13 +878,13 @@ proc sl_ignore {ihost hand flood} {
       if {[matchattr $hand f|f $chan]} {return 0}
     }
   }
-  if {![string match *!* $ihost]} {    
+  if {![string match *!* $ihost]} {
     foreach ignore [ignorelist] {
-      if {[string match [string tolower [lindex $ignore 0]] [string tolower $ihost]]} {
+      if {[string match [string tolower [lindex $ignore 0]] $ihost]} {
         return 0
       }
     }
-    set ihost *!*[string range $ihost [string first @ $ihost] end]
+    set ihost [sl_masktype $ihost]
     if {[isignore $ihost]} {return 0}
   } else {
     if {[isignore $ihost]} {return 0}
@@ -879,6 +899,7 @@ proc sl_ignore {ihost hand flood} {
   return 1
 }
 
+# queuereset procs allow all queue timers to be killed easily
 proc sl_ccqueuereset {chan} {
   global sl_ccqueue
   incr sl_ccqueue($chan) -1
@@ -1081,7 +1102,7 @@ proc sl_quicklock {chan} {
 }
 
 proc sl_dcc {hand idx arg} {
-  global sl_avflood sl_ban sl_banmax sl_bcflood sl_boban sl_boflood sl_bmflood sl_bxsimul sl_bfmaxbans sl_ccflood sl_globalban sl_igtime sl_jflood sl_kicks sl_lockcmds sl_lockflags sl_ilocktime sl_mlocktime sl_nkflood sl_note sl_shortlock sl_tsunami sl_txflood
+  global sl_avflood sl_ban sl_banmax sl_bcflood sl_boban sl_boflood sl_bmflood sl_bxsimul sl_bfmaxbans sl_ccflood sl_detectquits sl_globalban sl_igtime sl_jflood sl_kicks sl_lockcmds sl_lockflags sl_ilocktime sl_mlocktime sl_nkflood sl_note sl_shortlock sl_tsunami sl_txflood
   putcmdlog "#$hand# sentinel $arg"
   putidx $idx "This bot is protected by sentinel.tcl by slennox"
   putidx $idx "Current settings"
@@ -1120,10 +1141,15 @@ proc sl_dcc {hand idx arg} {
   } else {
     putidx $idx "- Channel BOGUS flood:      [lindex $sl_boflood 0] in [lindex $sl_boflood 1] secs"
   }
+  if {$sl_detectquits} {
+    set detectquits "quit detection ON"
+  } else {
+    set detectquits "quit detection OFF"
+  }
   if {[lsearch -exact $sl_jflood 0] != -1} {
     putidx $idx "- Channel JOIN-PART flood:  Off"
   } else {
-    putidx $idx "- Channel JOIN-PART flood:  [lindex $sl_jflood 0] in [lindex $sl_jflood 1] secs"
+    putidx $idx "- Channel JOIN-PART flood:  [lindex $sl_jflood 0] in [lindex $sl_jflood 1] secs ($detectquits)"
   }
   if {[lsearch -exact $sl_nkflood 0] != -1} {
     putidx $idx "- Channel NICK flood:       Off"
@@ -1161,9 +1187,9 @@ proc sl_dcc {hand idx arg} {
   }
   if {$sl_ban || [lsearch -exact $sl_boflood 0] == -1} {
     if {$sl_globalban} {
-      putidx $idx "- Ban type:                 Global"
+      putidx $idx "- Ban type:                 Global [sl_masktype nick@host.domain]"
     } else {
-      putidx $idx "- Ban type:                 Channel-specific"
+      putidx $idx "- Ban type:                 Channel-specific [sl_masktype nick@host.domain]"
     }
   }
   if {$sl_ban || [lsearch -exact $sl_boflood 0] == -1} {
@@ -1267,16 +1293,7 @@ proc sl_unsetarray {chan} {
   global sl_avbanhost sl_avbannick sl_avqueue sl_bfull sl_bobanhost sl_bobannick sl_boqueue sl_ccbanhost sl_ccbannick sl_ccqueue sl_flooded sl_jbanhost sl_jbannick sl_jqueue sl_locked sl_nkbanhost sl_nkflooding sl_nkqueue sl_pbanhost sl_pbannick sl_pqueue sl_txqueue sl_unlocked
   set chan [string tolower $chan]
   if {![validchan $chan] && [info exists sl_flooded($chan)]} {
-    unset sl_flooded($chan) ; unset sl_locked($chan) ; unset sl_unlocked($chan)
-    unset sl_nkflooding($chan)
-    unset sl_ccqueue($chan) ; unset sl_ccbanhost($chan) ; unset sl_ccbannick($chan)
-    unset sl_avqueue($chan) ; unset sl_avbanhost($chan) ; unset sl_avbannick($chan)
-    unset sl_txqueue($chan)
-    unset sl_nkqueue($chan) ; unset sl_nkbanhost($chan)
-    unset sl_boqueue($chan) ; unset sl_bobanhost($chan) ; unset sl_bobannick($chan)
-    unset sl_jqueue($chan) ; unset sl_jbanhost($chan) ; unset sl_jbannick($chan)
-    unset sl_pqueue($chan) ; unset sl_pbanhost($chan) ; unset sl_pbannick($chan)
-    unset sl_bfull($chan)
+    unset sl_flooded($chan) sl_locked($chan) sl_unlocked($chan) sl_nkflooding($chan) sl_ccqueue($chan) sl_ccbanhost($chan) sl_ccbannick($chan) sl_avqueue($chan) sl_avbanhost($chan) sl_avbannick($chan) sl_txqueue($chan) sl_nkqueue($chan) sl_nkbanhost($chan) sl_boqueue($chan) sl_bobanhost($chan) sl_bobannick($chan) sl_jqueue($chan) sl_jbanhost($chan) sl_jbannick($chan) sl_pqueue($chan) sl_pbanhost($chan) sl_pbannick($chan) sl_bfull($chan)
   }
   return 0
 }
@@ -1300,6 +1317,16 @@ proc sl_killutimer {cmd} {
   return $n
 }
 
+proc sl_masktype {uhost} {
+  global sl_masktype
+  switch -exact -- $sl_masktype {
+    0 {return *!*[string range $uhost [string first @ $uhost] end]}
+    1 {return *!*$uhost}
+    2 {return *!*[lindex [split [maskhost $uhost] "!"] 1]}
+  }
+  return
+}
+
 if {![info exists sl_unlocked] && ![string match *sl_settimer* [utimers]]} {
   utimer 3 sl_settimer
 }
@@ -1362,8 +1389,8 @@ bind dcc $sl_lockflags|$sl_lockflags lock sl_dcclc
 bind dcc $sl_lockflags|$sl_lockflags unlock sl_dccuc
 if {!$sl_lockcmds} {
   unbind pub $sl_lockflags|$sl_lockflags lc sl_lc
-  rename sl_lc ""
   unbind pub $sl_lockflags|$sl_lockflags uc sl_uc
+  rename sl_lc ""
   rename sl_uc ""
 }
 bind dcc m|m sentinel sl_dcc
@@ -1399,10 +1426,17 @@ if {[lsearch -exact $sl_nkflood 0] != -1} {
 }
 bind join - * sl_jflood
 bind part - * sl_pflood
+bind sign - * sl_pflood
+if {![info exists sl_detectquits]} {
+  set sl_detectquits 0
+}
+if {!$sl_detectquits} {
+  unbind sign - * sl_pflood
+}
 bind kick - * sl_pfloodk
 bind flud - * sl_flud
 bind mode - * sl_mode
 
-putlog "Loaded sentinel.tcl v2.60 by slennox"
+putlog "Loaded sentinel.tcl v2.70 by slennox"
 
 return
