@@ -4,11 +4,11 @@
  *   disconnect on a dcc socket
  *   ...and that's it!  (but it's a LOT)
  *
- * $Id: dcc.c,v 1.93 2010/06/29 15:52:24 thommey Exp $
+ * $Id: dcc.c,v 1.95 2011/10/02 18:21:35 pseudo Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1581,7 +1581,7 @@ static void dcc_telnet_new(int idx, char *buf, int x)
     strip_telnet(dcc[idx].sock, buf, &x);
   dcc[idx].timeval = now;
   for (x = 0; x < strlen(buf); x++)
-    if ((buf[x] <= 32) || (buf[x] >= 127))
+    if (buf[x] <= 32)
       ok = 0;
   if (!ok) {
     dprintf(idx, "\nYou can't use weird symbols in your nick.\n");
