@@ -4,11 +4,11 @@
  *
  *   IF YOU ALTER THIS FILE, YOU NEED TO RECOMPILE THE BOT.
  *
- * $Id: eggdrop.h,v 1.78 2010/06/29 15:52:24 thommey Exp $
+ * $Id: eggdrop.h,v 1.81 2011/07/09 15:07:48 thommey Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -195,7 +195,15 @@
 /* Yikes...who would have thought finding a usable random() would be so much
  * trouble?
  * Note: random(), rand(), and lrand48() are *not* thread safe.
+ *
+ * QNX doesn't include random() and srandom() in libc.so, only in libc.a
+ * So we can only use these functions in static builds on QNX.
  */
+#if defined QNX_HACKS && defined MAKING_MODS
+#  undef HAVE_RANDOM
+#  undef HAVE_SRANDOM
+#endif
+
 #ifdef HAVE_RANDOM
   /* On systems with random(), RANDOM_MAX may or may not be defined.
    *
@@ -244,7 +252,7 @@
 /* Use high-order bits for getting the random integer. With a modern
  * random() implmentation, modulo would probably be sufficient, but on
  * systems lacking random(), it may just be a macro for an older rand()
- * fucntion.
+ * function.
  */
 #define randint(n) (unsigned long) (random() / (RANDOM_MAX + 1.0) * n)
 
@@ -270,6 +278,7 @@ typedef int socklen_t;
  *    Handy aliases for memory tracking and core dumps
  */
 
+#define nstrdup(x)    n_strdup((x),__FILE__,__LINE__)
 #define nmalloc(x)    n_malloc((x),__FILE__,__LINE__)
 #define nrealloc(x,y) n_realloc((x),(y),__FILE__,__LINE__)
 #define nfree(x)      n_free((x),__FILE__,__LINE__)
