@@ -3,11 +3,11 @@
  *   memory allocation and deallocation
  *   keeping track of what memory is being used by whom
  *
- * $Id: mem.c,v 1.29 2010/01/03 13:27:32 pseudo Exp $
+ * $Id: mem.c,v 1.32 2011/08/15 18:16:29 thommey Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -304,22 +304,12 @@ void debug_mem_to_dcc(int idx)
   tell_netdebug(idx);
 }
 
-void *n_malloc(int size, const char *file, int line)
-{
-  void *x;
-
 #ifdef DEBUG_MEM
+static inline void addtomemtbl(void *x, int size, const char *file, int line)
+{
   int i = 0;
   char *p;
-#endif
 
-  x = (void *) malloc(size);
-  if (x == NULL) {
-    putlog(LOG_MISC, "*", "*** FAILED MALLOC %s (%d) (%d): %s", file, line,
-           size, strerror(errno));
-    fatal("Memory allocation failed", 0);
-  }
-#ifdef DEBUG_MEM
   if (lastused == MEMTBLSIZE) {
     putlog(LOG_MISC, "*", "*** MEMORY TABLE FULL: %s (%d)", file, line);
     fatal("Memory table full", 0);
@@ -333,6 +323,33 @@ void *n_malloc(int size, const char *file, int line)
   memtbl[i].file[19] = 0;
   memused += size;
   lastused++;
+}
+#endif
+
+char *n_strdup(const char *s, const char *file, int line)
+{
+  char *x;
+
+  x = egg_strdup(s);
+/* compat strdup uses nmalloc itself */
+#if defined(DEBUG_MEM) && defined(HAVE_STRDUP)
+  addtomemtbl(x, strlen(s)+1, file, line);
+#endif
+  return x;
+}
+
+void *n_malloc(int size, const char *file, int line)
+{
+  void *x;
+
+  x = (void *) malloc(size);
+  if (x == NULL) {
+    putlog(LOG_MISC, "*", "*** FAILED MALLOC %s (%d) (%d): %s", file, line,
+           size, strerror(errno));
+    fatal("Memory allocation failed", 0);
+  }
+#ifdef DEBUG_MEM
+  addtomemtbl(x, size, file, line);
 #endif
   return x;
 }
