@@ -7,11 +7,11 @@
  *   help system
  *   motd display and %var substitution
  *
- * $Id: misc.c,v 1.86 2010/06/29 15:52:24 thommey Exp $
+ * $Id: misc.c,v 1.88 2011/07/09 15:07:48 thommey Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1550,6 +1550,13 @@ void str_unescape(char *str, register const char esc_char)
   (void) strchr_unescape(str, 0, esc_char);
 }
 
+char *str_dup(const char *s)
+{
+  char *d = nmalloc(strlen(s)+1);
+  strcpy(d, s);
+  return d;
+}
+
 /* Kills the bot. s1 is the reason shown to other bots,
  * s2 the reason shown on the partyline. (Sup 25Jul2001)
  */
