@@ -2,11 +2,11 @@
  * channels.c -- part of channels.mod
  *   support for channels within the bot
  *
- * $Id: channels.c,v 1.107 2010/07/10 14:54:49 pseudo Exp $
+ * $Id: channels.c,v 1.109 2011/07/20 10:50:35 thommey Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -368,6 +368,10 @@ static char *convert_element(char *src, char *dst)
   int flags;
 
   Tcl_ScanElement(src, &flags);
+/* Work around Tcl bug 3371644 (only present in 8.5.10) */
+#ifdef TCL_DONT_QUOTE_HASH
+  flags |= TCL_DONT_QUOTE_HASH;
+#endif
   Tcl_ConvertElement(src, dst, flags);
   return dst;
 }
