@@ -1,11 +1,11 @@
 /*
  * share.c -- part of share.mod
  *
- * $Id: share.c,v 1.92 2010/02/18 09:52:30 pseudo Exp $
+ * $Id: share.c,v 1.94 2011/10/02 20:11:06 pseudo Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1947,10 +1947,11 @@ static void start_sending_users(int idx)
             q_tbuf(dcc[idx].nick, s2, NULL);
           }
           /* Send address */
-          if (bi)
+          if (bi) {
             egg_snprintf(s2, sizeof s2, "s c BOTADDR %s %s %d %d\n", u->handle,
                          bi->address, bi->telnet_port, bi->relay_port);
-          q_tbuf(dcc[idx].nick, s2, NULL);
+            q_tbuf(dcc[idx].nick, s2, NULL);
+          }
           fr.match = FR_GLOBAL;
           fr.global = u->flags;
 
