@@ -4,11 +4,11 @@
  *
  * by Darrin Smith (beldin@light.iinet.net.au)
  *
- * $Id: modules.c,v 1.108 2010/07/08 19:23:06 pseudo Exp $
+ * $Id: modules.c,v 1.110 2011/07/09 15:07:48 thommey Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -576,7 +576,8 @@ Function global_table[] = {
   /* 296 - 299 */
   (Function) check_conflags,
   (Function) increase_socks_max,
-  (Function) log_ts
+  (Function) log_ts,
+  (Function) mod_strdup
 };
 
 void init_modules(void)
@@ -941,6 +942,20 @@ int module_undepend(char *name1)
   return ok;
 }
 
+char *mod_strdup(const char *s, const char *modname, const char *filename, int line)
+{
+#ifdef DEBUG_MEM
+  char x[100], *p;
+
+  p = strrchr(filename, '/');
+  egg_snprintf(x, sizeof x, "%s:%s", modname, p ? p + 1 : filename);
+  x[19] = 0;
+  return n_strdup(s, x, line);
+#else
+  return nstrdup(s);
+#endif
+}
+
 void *mod_malloc(int size, const char *modname, const char *filename, int line)
 {
 #ifdef DEBUG_MEM
