@@ -2,11 +2,11 @@
  * tclegg.h
  *   stuff used by tcl.c and tclhash.c
  *
- * $Id: tclegg.h,v 1.40 2010/06/29 15:52:24 thommey Exp $
+ * $Id: tclegg.h,v 1.42 2011/07/09 15:07:48 thommey Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -106,6 +106,27 @@ typedef struct timer_str {
   unsigned long id;             /* Used to remove timers                */
 } tcl_timer_t;
 
+/* Callback that's called after executing a Tcl code snippet.
+ * The arguments are: context, script, resultcode, resultstring, dofree.
+ * If dofree is 1, the callback *must* nfree() both context and script.
+ * resultcode is -1 if the execution is stopped (kill_tcl()).
+ */
+typedef void (*tcleventcallback)(char *, char *, int, const char *, int);
+
+/* This schedules a code snippet to execute, if necessary. */
+void do_tcl_async(char *, char *, tcleventcallback);
+
+#ifdef REPLACE_NOTIFIER
+
+/* Tcl code snippet queue structure */
+typedef struct tclevent {
+  char *script;
+  void *context;
+  tcleventcallback callback;
+  struct tclevent *next;
+} tclevent_t;
+
+#endif
 
 /* Used for Tcl stub functions */
 #define STDVAR (cd, irp, argc, argv)                                    \
@@ -176,6 +197,7 @@ void add_tcl_coups(tcl_coups *);
 void rem_tcl_coups(tcl_coups *);
 void add_tcl_ints(tcl_ints *);
 void rem_tcl_ints(tcl_ints *);
+void do_tcl_sync(char *, char *, tcleventcallback, int);
 const char *tcl_resultstring();
 int tcl_resultint();
 int tcl_resultempty();
