@@ -1,11 +1,11 @@
 /*
  * tclhash.h
  *
- * $Id: tclhash.h,v 1.25 2010/07/12 15:40:52 thommey Exp $
+ * $Id: tclhash.h,v 1.27 2011/07/31 20:15:06 thommey Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2010 Eggheads Development Team
+ * Copyright (C) 1999 - 2011 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,7 +39,8 @@ typedef struct tcl_cmd_b {
 } tcl_cmd_t;
 
 struct threaddata {
-  int (*mainloopfunc)(int);     /* main loop function */
+  int (*mainloopfunc)(int);     /* main loop function replacing a single
+                                 * tcl event loop iteration */
   sock_list *socklist;          /* tcl socket list for threads, else NULL */
   struct timeval blocktime;     /* maximum time to block in select() */
   int mainthread;               /* Is this the main thread? */
